#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Enter the description of your strategy here
    /// </summary>
    [Description("Enter the description of your strategy here")]
    public class ZsRSIStochSMA : Strategy
    {
        #region Variables
        
        private int periodoRSI = 3;
		private int periodoSMA = 150;
        private int stochD = 3;
        private int stochK = 6;
        private int stochSmooth = 3;
        
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose = true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (
					( Position.MarketPosition == MarketPosition.Short || Position.MarketPosition == MarketPosition.Flat )
				
					// El cierre por encima de la media
				&&	( Close[0] > SMA(Close, periodoSMA)[0] )
				
					// El RSI por debajo de 20
				&&	( RSI( Close, periodoRSI, 1 )[0] < 20.0 )
				
					// El Stochastic por debajo de 30 ... 
				&& 	( 		Stochastics( Close, stochD, stochK, stochSmooth ).Values[0][0] < 30.0 //D
						&& 	Stochastics( Close, stochD, stochK, stochSmooth ).Values[1][0] < 30.0 //K
					// ... y cruzando al alza
						&& 	Stochastics( Close, stochD, stochK, stochSmooth ).Values[1][0] >
							Stochastics( Close, stochD, stochK, stochSmooth ).Values[0][0]
						&&  Stochastics( Close, stochD, stochK, stochSmooth ).Values[1][1] < 
						  	Stochastics( Close, stochD, stochK, stochSmooth ).Values[0][1] )
				)
			{
				EnterLong( 1, "EntrarLargo");
			}
			
			if ( 
					( Position.MarketPosition == MarketPosition.Long || Position.MarketPosition == MarketPosition.Flat )
				
					// El cierre por debajo de la media
				&&	( Close[0] < SMA(Close, periodoSMA)[0] )
				
					// El RSI por encima de 80
				&&	( RSI( Close, periodoRSI, 1 )[0] > 80.0 )
				
					// El Stochastic por encima de 70 ... 
				&& 	( 		Stochastics( Close, stochD, stochK, stochSmooth ).Values[0][0] > 70.0 //D
						&& 	Stochastics( Close, stochD, stochK, stochSmooth ).Values[1][0] > 70.0 //K
					// ... y cruzando a la baja
						&& 	Stochastics( Close, stochD, stochK, stochSmooth ).Values[1][0] <
							Stochastics( Close, stochD, stochK, stochSmooth ).Values[0][0]
						&&  Stochastics( Close, stochD, stochK, stochSmooth ).Values[1][1] > 
						  	Stochastics( Close, stochD, stochK, stochSmooth ).Values[0][1] )
				)
			{
				EnterShort( 1, "EntrarCorto" );
			}
			
			
			
				
        }

        #region Properties
        [Description("")]
        [Category("Parameters")]
        public int PeriodoRSI
        {
            get { return periodoRSI; }
            set { periodoRSI = Math.Max(1, value); }
        }

		[Description("")]
        [Category("Parameters")]
        public int PeriodoSMA
        {
            get { return periodoSMA; }
            set { periodoSMA = Math.Max(1, value); }
        }
		
        [Description("")]
        [Category("Parameters")]
        public int StochD
        {
            get { return stochD; }
            set { stochD = Math.Max(1, value); }
        }

        [Description("")]
        [Category("Parameters")]
        public int StochK
        {
            get { return stochK; }
            set { stochK = Math.Max(1, value); }
        }

        [Description("")]
        [Category("Parameters")]
        public int StochSmooth
        {
            get { return stochSmooth; }
            set { stochSmooth = Math.Max(1, value); }
        }
        #endregion
    }
}
